transform_image
transform_image(files, height=32, max_width=None)Load and resize image(s) to a fixed height, preserving aspect ratio.
Returns a 4D tensor (B, 3, H, W). When passing a batch with different widths, images are padded to the maximum width in the batch (or max_width if given).